@@ -188,7 +188,7 @@ msgstr "Bahr"
         out_buf = BytesIO()
         pofile.write_po(out_buf, catalog, omit_header=True)
         assert out_buf.getvalue().strip() == buf.getvalue().strip(), \
-                                                            out_buf.getvalue()
+            out_buf.getvalue()
 
     def test_with_context_two(self):
         buf = BytesIO(b'''msgctxt "Menu"
@@ -299,7 +299,7 @@ not be removed
         catalog.add(text, locations=[('main.py', 1)])
         buf = BytesIO()
         pofile.write_po(buf, catalog, no_location=True, omit_header=True,
-                         width=42)
+                        width=42)
         self.assertEqual(b'''msgid ""
 "Here's some text where\\n"
 "white space and line breaks matter, and"
@@ -317,7 +317,7 @@ includesareallylongwordthatmightbutshouldnt throw us into an infinite loop
         catalog.add(text, locations=[('main.py', 1)])
         buf = BytesIO()
         pofile.write_po(buf, catalog, no_location=True, omit_header=True,
-                         width=32)
+                        width=32)
         self.assertEqual(b'''msgid ""
 "Here's some text that\\n"
 "includesareallylongwordthatmightbutshouldnt"
@@ -513,6 +513,15 @@ msgstr[0] "Voh"
 msgstr[1] "Voeh"''' in value
         assert value.find(b'msgid ""') < value.find(b'msgid "bar"') < value.find(b'msgid "foo"')
 
+    def test_file_sorted_po(self):
+        catalog = Catalog()
+        catalog.add(u'bar', locations=[('utils.py', 3)])
+        catalog.add((u'foo', u'foos'), (u'Voh', u'Voeh'), locations=[('main.py', 1)])
+        buf = BytesIO()
+        pofile.write_po(buf, catalog, sort_by_file=True)
+        value = buf.getvalue().strip()
+        assert value.find(b'main.py') < value.find(b'utils.py')
+
     def test_file_with_no_lineno(self):
         catalog = Catalog()
         catalog.add(u'bar', locations=[('utils.py', None)],
